==> turbine-4.0.1-source.zip: turbine-4.0.1/src/test/org/apache/turbine/services/security/TurbineDefaultModelManagerTest.java <==
package org.apache.turbine.services.security;
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import static org.junit.Assert.fail;

import org.apache.fulcrum.security.model.turbine.test.AbstractTurbineModelManagerTest;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * Test Fulcrum Integration.
 *
 * Stub for further tests, relying on Fulcrum.
 *
 * @author gkallidis
 * @version $Id:$
 */
public class TurbineDefaultModelManagerTest
    extends AbstractTurbineModelManagerTest
{

    @Override
	@Before
	public void setUp() throws Exception
    {
        try
        {
        	// just Fulcrum
            setConfigurationFileName("conf/test/fulcrumComponentConfiguration.xml");
            setRoleFileName("conf/test/fulcrumRoleConfiguration.xml");
            super.setUp();

        }
        catch (Exception e)
        {
            fail(e.toString());
        }
    }

    @Test
    public void testDummy() {
    	// all tests in abstract
    }

    @Override
    @After
	public void tearDown()
    {
        modelManager = null;
        securityService = null;
    }

}

==> turbine-7.0-source.zip: turbine-7.0/src/test/org/apache/turbine/services/security/TurbineDefaultModelManagerTest.java <==
package org.apache.turbine.services.security;
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


import static org.junit.jupiter.api.Assertions.fail;

import org.apache.fulcrum.security.model.turbine.test.AbstractTurbineModelManagerTest;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;


/**
 * Test Fulcrum Integration.
 *
 * Stub for further tests, relying on Fulcrum.
 *
 * @author gkallidis
 * @version $Id:$
 */
public class TurbineDefaultModelManagerTest
    extends AbstractTurbineModelManagerTest
{

    @Override
	@BeforeEach
	public void setUp() throws Exception
    {
        try
        {
        	// just Fulcrum
            setConfigurationFileName("conf/test/fulcrumComponentConfiguration.xml");
            setRoleFileName("conf/test/fulcrumRoleConfiguration.xml");
            super.setUp();

        }
        catch (Exception e)
        {
            fail(e.toString());
        }
    }

    @Test
    public void testDummy() {
    	// all tests in abstract
    }

    @Override
    @AfterEach
	public void tearDown()
    {
        modelManager = null;
        securityService = null;
        super.tearDown();
    }

}
